@@ -28,7 +28,7 @@ from libopensesame.exceptions import osexception
 from openexp.keyboard import keyboard
 import wave
 
-VERSION = u'2020.11-1'
+VERSION = u'2021.03-1'
 
 class audio_low_latency_play(item):
 
@@ -56,6 +56,7 @@ class audio_low_latency_play(item):
         self.var.duration = u'sound'
         self.var.delay = 0
         self.var.pause_resume = u''
+        self.var.stop = u''
         self.var.ram_cache = u'yes'
 
 
@@ -82,6 +83,7 @@ class audio_low_latency_play(item):
 
         self.filename = self.experiment.pool[self.var.filename]
         self.pause_resume = self.var.pause_resume
+        self.stop = self.var.stop
         self.ram_cache = self.var.ram_cache
 
 
@@ -99,13 +101,23 @@ class audio_low_latency_play(item):
 
         if self.pause_resume != u'':
             # Prepare the pause resume responses
-            self._allowed_responses = []
+            self._allowed_responses_pause_resume = []
             for r in safe_decode(self.pause_resume).split(u';'):
                 if r.strip() != u'':
-                    self._allowed_responses.append(r)
-            if not self._allowed_responses:
-                self._allowed_responses = None
-            self.show_message(u"allowed pause/resume keys set to %s" % self._allowed_responses)
+                    self._allowed_responses_pause_resume.append(r)
+            if not self._allowed_responses_pause_resume:
+                self._allowed_responses_pause_resume = None
+            self.show_message(u"allowed pause/resume keys set to %s" % self._allowed_responses_pause_resume)
+
+        if self.stop != u'':
+            # Prepare the pause resume responses
+            self._allowed_responses_stop = []
+            for r in safe_decode(self.stop).split(u';'):
+                if r.strip() != u'':
+                    self._allowed_responses_stop.append(r)
+            if not self._allowed_responses_stop:
+                self._allowed_responses_stop = None
+            self.show_message(u"allowed stop keys set to %s" % self._allowed_responses_stop)
 
         if self.dummy_mode == u'no':
             try:
@@ -193,8 +205,14 @@ class audio_low_latency_play(item):
             self.show_message(u'Starting audio playback')
 
 
-            if self.pause_resume != u'':
-                self.kb.keylist = self._allowed_responses
+            if self.pause_resume != u'' or self.stop != u'':
+                _keylist = list()
+                if self.pause_resume != u'':
+                    _keylist.extend(self._allowed_responses_pause_resume)
+                if self.stop != u'':
+                    _keylist.extend(self._allowed_responses_stop)
+
+                self.kb.keylist = _keylist
                 self.kb.flush()
 
             if self.ram_cache == u'No':
@@ -234,17 +252,23 @@ class audio_low_latency_play(item):
             if self.duration_check:
                 if self.clock.time() - start_time >= self.duration:
                     break
-            if self.pause_resume != u'':
+            if self.pause_resume != u'' or self.stop != u'':
                 key1, time1 = self.kb.get_key()
-                if key1 in self._allowed_responses:
+                if key1 in self._allowed_responses_stop:
+                    self.kb.flush()
+                    self.show_message(u'Stopped audio playback')
+                    break
+                elif key1 in self._allowed_responses_pause_resume:
                     self.kb.flush()
                     self.show_message(u'Paused audio playback')
                     while True:
                         key2, time2 = self.kb.get_key()
-                        if key2 in self._allowed_responses:
+                        if key2 in self._allowed_responses_pause_resume:
+                            self.kb.flush()
                             self.show_message(u'Resumed audio playback')
                             break
 
+
         if self.module == self.experiment.sounddevice_module_name:
             stream.stop()
         elif self.module == self.experiment.pyaudio_module_name:
@@ -277,14 +301,19 @@ class audio_low_latency_play(item):
             if self.duration_check:
                 if self.clock.time() - start_time >= self.duration:
                     break
-            if self.pause_resume != u'':
+            if self.pause_resume != u'' or self.stop != u'':
                 key1, time1 = self.kb.get_key()
-                if key1 in self._allowed_responses:
+                if key1 in self._allowed_responses_stop:
+                    self.kb.flush()
+                    self.show_message(u'Stopped audio playback')
+                    break
+                elif key1 in self._allowed_responses_pause_resume:
                     self.kb.flush()
                     self.show_message(u'Paused audio playback')
                     while True:
                         key2, time2 = self.kb.get_key()
-                        if key2 in self._allowed_responses:
+                        if key2 in self._allowed_responses_pause_resume:
+                            self.kb.flush()
                             self.show_message(u'Resumed audio playback')
                             break
 
