@@ -29,7 +29,7 @@ from openexp.keyboard import keyboard
 import threading
 import wave
 
-VERSION = u'2020.11-1'
+VERSION = u'2021.03-1'
 
 class audio_low_latency_play_start(item):
 
@@ -57,6 +57,7 @@ class audio_low_latency_play_start(item):
         self.var.duration = u'sound'
         self.var.delay = 0
         self.var.pause_resume = u''
+        self.var.stop = u''
         self.var.ram_cache = u'yes'
 
 
@@ -83,10 +84,12 @@ class audio_low_latency_play_start(item):
 
         self.filename = self.experiment.pool[self.var.filename]
         self.pause_resume = self.var.pause_resume
+        self.stop = self.var.stop
         self.ram_cache = self.var.ram_cache
 
         self.experiment.audio_low_latency_play_continue = 1
         self.experiment.audio_low_latency_play_start = 1
+        self.experiment.audio_low_latency_play_execute_pause = 0
 
 
     def prepare(self):
@@ -103,13 +106,23 @@ class audio_low_latency_play_start(item):
 
         if self.pause_resume != u'':
             # Prepare the pause resume responses
-            self._allowed_responses = []
+            self._allowed_responses_pause_resume = []
             for r in safe_decode(self.pause_resume).split(u';'):
                 if r.strip() != u'':
-                    self._allowed_responses.append(r)
-            if not self._allowed_responses:
-                self._allowed_responses = None
-            self.show_message(u"allowed pause/resume keys set to %s" % self._allowed_responses)
+                    self._allowed_responses_pause_resume.append(r)
+            if not self._allowed_responses_pause_resume:
+                self._allowed_responses_pause_resume = None
+            self.show_message(u"allowed pause/resume keys set to %s" % self._allowed_responses_pause_resume)
+
+        if self.stop != u'':
+            # Prepare the pause resume responses
+            self._allowed_responses_stop = []
+            for r in safe_decode(self.stop).split(u';'):
+                if r.strip() != u'':
+                    self._allowed_responses_stop.append(r)
+            if not self._allowed_responses_stop:
+                self._allowed_responses_stop = None
+            self.show_message(u"allowed stop keys set to %s" % self._allowed_responses_stop)
 
         if self.dummy_mode == u'no':
             try:
@@ -202,8 +215,14 @@ class audio_low_latency_play_start(item):
             self.show_message(u'Starting audio playback')
             self.experiment.audio_low_latency_play_locked = 1
 
-            if self.pause_resume != u'':
-                self.kb.keylist = self._allowed_responses
+            if self.pause_resume != u'' or self.stop != u'':
+                _keylist = list()
+                if self.pause_resume != u'':
+                    _keylist.extend(self._allowed_responses_pause_resume)
+                if self.stop != u'':
+                    _keylist.extend(self._allowed_responses_stop)
+
+                self.kb.keylist = _keylist
                 self.kb.flush()
 
             if self.ram_cache == u'no':
@@ -248,14 +267,24 @@ class audio_low_latency_play_start(item):
             elif self.duration_check:
                 if self.clock.time() - start_time >= self.duration:
                     break
-            if self.pause_resume != u'':
+            if self.experiment.audio_low_latency_play_execute_pause == 1:
+                self.show_message(u'Paused audio playback')
+                while self.experiment.audio_low_latency_play_execute_pause == 1:
+                    pass
+                self.show_message(u'Resumed audio playback')
+            if self.pause_resume != u'' or self.stop != u'':
                 key1, time1 = self.kb.get_key()
-                if key1 in self._allowed_responses:
+                if key1 in self._allowed_responses_stop:
+                    self.kb.flush()
+                    self.show_message(u'Stopped audio playback')
+                    break
+                elif key1 in self._allowed_responses_pause_resume:
                     self.kb.flush()
                     self.show_message(u'Paused audio playback')
                     while True:
                         key2, time2 = self.kb.get_key()
-                        if key2 in self._allowed_responses:
+                        if key2 in self._allowed_responses_pause_resume:
+                            self.kb.flush()
                             self.show_message(u'Resumed audio playback')
                             break
 
@@ -299,14 +328,24 @@ class audio_low_latency_play_start(item):
             elif self.duration_check:
                 if self.clock.time() - start_time >= self.duration:
                     break
-            if self.pause_resume != u'':
+            if self.experiment.audio_low_latency_play_execute_pause == 1:
+                self.show_message(u'Paused audio playback')
+                while self.experiment.audio_low_latency_play_execute_pause == 1:
+                    pass
+                self.show_message(u'Resumed audio playback')
+            if self.pause_resume != u'' or self.stop != u'':
                 key1, time1 = self.kb.get_key()
-                if key1 in self._allowed_responses:
+                if key1 in self._allowed_responses_stop:
+                    self.kb.flush()
+                    self.show_message(u'Stopped audio playback')
+                    break
+                elif key1 in self._allowed_responses_pause_resume:
                     self.kb.flush()
                     self.show_message(u'Paused audio playback')
                     while True:
                         key2, time2 = self.kb.get_key()
-                        if key2 in self._allowed_responses:
+                        if key2 in self._allowed_responses_pause_resume:
+                            self.kb.flush()
                             self.show_message(u'Resumed audio playback')
                             break
 
