@@ -29,7 +29,7 @@ from openexp.keyboard import keyboard
 import threading
 import wave
 
-VERSION = u'2020.11-1'
+VERSION = u'2021.03-1'
 
 class audio_low_latency_record_start(item):
 
@@ -56,7 +56,7 @@ class audio_low_latency_record_start(item):
         self.var.filename = u''
         self.var.duration = u'infinite'
         self.var.delay = 0
-        self.var.pause_resume = u''
+        self.var.stop = u''
         self.var.bitdepth = str(16)
         self.var.samplerate = str(44100)
         self.var.channels = str(1)
@@ -86,11 +86,12 @@ class audio_low_latency_record_start(item):
                     u'Audio Low Latency Record Init item is missing')
 
         self.filename = self.experiment.pool[self.var.filename]
-        self.pause_resume = self.var.pause_resume
+        self.stop = self.var.stop
         self.ram_cache = self.var.ram_cache
 
         self.experiment.audio_low_latency_record_continue = 1
         self.experiment.audio_low_latency_record_start = 1
+        self.experiment.audio_low_latency_record_execute_pause = 0
 
 
     def prepare(self):
@@ -105,15 +106,15 @@ class audio_low_latency_record_start(item):
 
         self.init_var()
 
-        if self.pause_resume != u'':
+        if self.stop != u'':
             # Prepare the pause resume responses
-            self._allowed_responses = []
-            for r in safe_decode(self.pause_resume).split(u';'):
+            self._allowed_responses_stop = []
+            for r in safe_decode(self.stop).split(u';'):
                 if r.strip() != u'':
-                    self._allowed_responses.append(r)
-            if not self._allowed_responses:
-                self._allowed_responses = None
-            self.show_message(u"allowed pause/resume keys set to %s" % self._allowed_responses)
+                    self._allowed_responses_stop.append(r)
+            if not self._allowed_responses_stop:
+                self._allowed_responses_stop = None
+            self.show_message(u"allowed stop keys set to %s" % self._allowed_responses_stop)
 
         if self.dummy_mode == u'no':
             try:
@@ -187,8 +188,10 @@ class audio_low_latency_record_start(item):
 
             self.show_message(u'Starting audio recording')
 
-            if self.pause_resume != u'':
-                self.kb.keylist = self._allowed_responses
+            if self.stop != u'':
+                _keylist = self._allowed_responses_stop
+
+                self.kb.keylist = _keylist
                 self.kb.flush()
 
             self.experiment.audio_low_latency_record_locked = 1
@@ -233,17 +236,13 @@ class audio_low_latency_record_start(item):
             elif self.ram_cache == u'no':
                 wav_file.writeframes(data)
 
-            if self.pause_resume != u'':
+            if self.stop != u'':
                 key1, time1 = self.kb.get_key()
-                if key1 in self._allowed_responses:
+                if key1 in self._allowed_responses_stop:
                     self.kb.flush()
-                    self.show_message(u'Paused audio recording')
-                    while True:
-                        key2, time2 = self.kb.get_key()
-                        if key2 in self._allowed_responses:
-                            self.show_message(u'Resumed audio recording')
-                            break
-
+                    self.show_message(u'Stopped audio recording')
+                    break
+  
             # check for stop
             if self.experiment.audio_low_latency_record_continue == 0:
                 break
